% Variance-based sensitivity indices (ROSA-VSI)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%        Reaction-Oriented Sensitivity Analysis        %%%%%%%%%%%
%%%%%%%%%%                   VSI COMPUTATION                    %%%%%%%%%%%
%%%%%%%%%%              Last Modified: 08/11/2009               %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% First-order calculations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% Calculate SESIs

sigmat = varfTT./varmTT;
sigmad = varfDD./varmDD;
sigmas = varfSS./varmSS;

% Calculate TESIs 

taut = 1 - varvTT./varmTT;
taud = 1 - varvDD./varmDD;
taus = 1 - varvSS./varmSS;

% Calculate JESIs

etat = taut - sigmat;
etad = taud - sigmad;
etas = taus - sigmas;

% Calculate delta

deltat = 1 - sum(sigmat);
deltad = 1 - sum(sigmad);
deltas = 1 - sum(sigmas);

deltat = deltat*(deltat > 0);
deltad = deltad*(deltad > 0);
deltas = deltas*(deltas > 0);

% Sort SESI values

[ssigmat,IT] = sort(sigmat);
[ssigmad,ID] = sort(sigmad);
[ssigmas,IS] = sort(sigmas);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Second-order calculations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% Calculate DESIs

sigma2t = var2fTT./varmmTT;
sigma2d = var2fDD./varmmDD;
sigma2s = var2fSS./varmmSS;

% Sort DESI values

for m = 1:M
    for n = 1:m
        sigma2t(m,n) = 0;  % set diagonal and lower left side of matrix to
        sigma2d(m,n) = 0;  % zero to avoid redundancy in sorting due 
        sigma2s(m,n) = 0;  % to symmetry
    end
end
        
for m = 1:M,
   vsigma2t((m-1)*M+1:m*M) = sigma2t(m,:);
   vsigma2d((m-1)*M+1:m*M) = sigma2d(m,:);
   vsigma2s((m-1)*M+1:m*M) = sigma2s(m,:);
end

[svsigma2t,I2T] = sort(vsigma2t);
[svsigma2d,I2D] = sort(vsigma2d);
[svsigma2s,I2S] = sort(vsigma2s);

% Calculate PESIs

for m = 1:M
    nut(m,1:M) = sigma2t(m,1:M) - sigmat(m) - sigmat(1:M);
    nud(m,1:M) = sigma2d(m,1:M) - sigmad(m) - sigmad(1:M);
    nus(m,1:M) = sigma2s(m,1:M) - sigmas(m) - sigmas(1:M);
end

nut = nut.*(nut > 0);
nud = nud.*(nud > 0);
nus = nus.*(nus > 0);

% Calculate gamma

gammat = 1 - sum(sigmat) - sum(sum(nut));
gammad = 1 - sum(sigmad) - sum(sum(nud));
gammas = 1 - sum(sigmas) - sum(sum(nus));

gammat = gammat*(gammat > 0);
gammad = gammad*(gammad > 0);
gammas = gammas*(gammas > 0);