% Derivative-Based SESI approximation (ROSA-DV)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%         Reaction-Oriented Sensitivity Analysis       %%%%%%%%%%%
%%%%%%%%%%             Derivative-Based Approximation           %%%%%%%%%%%
%%%%%%%%%%                Last Modified: 08/11/2009             %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Calculate response characteristics
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

for m = 1:M
	[TTf(m),DDf(m),SSf(m)] = featureit(species,qf(:,:,m),t,tresol,durtol);
    [TTb(m),DDb(m),SSb(m)] = featureit(species,qb(:,:,m),t,tresol,durtol);
end    

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Approximate SESIs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

sigmat = (TTf-TTb)./(2*delta);
sigmad = (DDf-DDb)./(2*delta);
sigmas = (SSf-SSb)./(2*delta);
        
sigmat = sigmat.^2./sum(sigmat.^2);
sigmad = sigmad.^2./sum(sigmad.^2);
sigmas = sigmas.^2./sum(sigmas.^2);    

% Sort SESIs

[setat,IT] = sort(sigmat);
[setad,ID] = sort(sigmad);
[setas,IS] = sort(sigmas);