% Write sensitivity results (ROSA-DV)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%         Reaction-Oriented Sensitivity Analysis       %%%%%%%%%%%
%%%%%%%%%%             Derivative-Based Approximation           %%%%%%%%%%%
%%%%%%%%%%                Last Modified: 08/11/2009             %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write SESIs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'APPROXIMATE (DV) REACTION CLASSIFICATION RESULTS (TIMING)');
fprintf(fid,'\n\nCPU time (in seconds) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of DV = %2.4f',delta);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n\n');
for m = 1:M
    Sens = [reac(m);sigmat(m)];
    if sigmat(m) <= theta
        fprintf(fid,'%1.0f\t%18.4f\t\t\tNON-INFLUENTIAL\n',Sens);
    else
        fprintf(fid,'%1.0f\t%18.4f\t\t\t****INFLUENTIAL\n',Sens);
    end
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'APPROXIMATE (DV) REACTION CLASSIFICATION RESULTS (DURATION)');
fprintf(fid,'\n\nCPU time (in seconds) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of DV = %2.4f',delta);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n\n');
for m = 1:M
    Sens = [reac(m);sigmad(m)];
    if sigmad(m) <= theta
        fprintf(fid,'%1.0f\t%18.4f\t\t\tNON-INFLUENTIAL\n',Sens);
    else
        fprintf(fid,'%1.0f\t%18.4f\t\t\t****INFLUENTIAL\n',Sens);
    end
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'APPROXIMATE (DV) REACTION CLASSIFICATION RESULTS (STRENGTH)');
fprintf(fid,'\n\nCPU time (in seconds) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of DV = %2.4f',delta);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n\n');
for m = 1:M
    Sens = [reac(m);sigmas(m)];
    if sigmas(m) <= theta
        fprintf(fid,'%1.0f\t%18.4f\t\t\tNON-INFLUENTIAL\n',Sens);
    else
        fprintf(fid,'%1.0f\t%18.4f\t\t\t****INFLUENTIAL\n',Sens);
    end
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write reaction ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'APPROXIMATE (DV) REACTION RANKING RESULTS (TIMING)');
fprintf(fid,'\n\nCPU time (in seconds) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of DV = %2.4f',delta);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n\n');
for m = 1:M
    Sens = [IT(M-m+1);setat(M-m+1)];
    if setat(M-m+1) > theta
        fprintf(fid,'%1.0f\t%18.4f\t\t\tINFLUENTIAL\n',Sens);
    end
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'APPROXIMATE (DV) REACTION RANKING RESULTS (DURATION)');
fprintf(fid,'\n\nCPU time (in seconds) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of DV = %2.4f',delta);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n\n');
for m = 1:M
    Sens = [ID(M-m+1);setad(M-m+1)];
    if setad(M-m+1) > theta
        fprintf(fid,'%1.0f\t%18.4f\t\t\tINFLUENTIAL\n',Sens);
    end
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'APPROXIMATE (DV) REACTION RANKING RESULTS (STRENGTH)');
fprintf(fid,'\n\nCPU time (in seconds) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of DV = %2.4f',delta);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nReaction\t\tSESI\t\t\tClassification\n\n');
for m = 1:M
    Sens = [IS(M-m+1);setas(M-m+1)];
    if setas(M-m+1) > theta
        fprintf(fid,'%1.0f\t%18.4f\t\t\tINFLUENTIAL\n',Sens);
    end
end
fclose(fid);