% Plot sensitivity results (ROSOSA-VSI)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%  Reaction and Species-Oriented Sensitivity Analysis  %%%%%%%%%%%
%%%%%%%%%%                   VSI COMPUTATION                    %%%%%%%%%%%
%%%%%%%%%%              Last Modified: 08/11/2009               %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

close all

figure
h = stem(fac,[etat;etad;etas]','--','k');
set(h(1),'MarkerFaceColor','blue','MarkerSize',8,'Marker','o')
set(h(2),'MarkerFaceColor','red','MarkerSize',8,'Marker','square')
set(h(3),'MarkerFaceColor','green','MarkerSize',8,'Marker','diamond')
axis([0 MN+1 -0.02 1.1*max(max(max(etat),max(etad)),max(etas))])
set(gca,'xtick',(1:2:MN),'FontSize',12)
legend('timing','duration','strength')
xlabel('reactions (1-21) & species (22-44)','FontSize',14)
ylabel('JESI','FontSize',14)
title('{\bf ROSOSA}','FontSize',14)
clear threshold
threshold(1:MN+2) = theta;
index = (0:MN+1);
hold on
plot(index,threshold)
saveas(gcf,'..\results\figures\jesi.fig') 

figure
h = stem(fac,[sigmat;sigmad;sigmas]','--','k');
set(h(1),'MarkerFaceColor','blue','MarkerSize',8,'Marker','o')
set(h(2),'MarkerFaceColor','red','MarkerSize',8,'Marker','square')
set(h(3),'MarkerFaceColor','green','MarkerSize',8,'Marker','diamond')
axis([0 MN+1 -0.04 1.1*max(max(max(sigmat),max(sigmad)),max(sigmas))])
set(gca,'xtick',(1:2:MN),'FontSize',12)
legend('timing','duration','strength')
xlabel('reactions (1-21) & species (22-44)','FontSize',14)
ylabel('SESI','FontSize',14)
title('{\bf ROSOSA}','FontSize',14)
clear threshold
threshold(1:MN+2) = theta;
index = (0:MN+1);
hold on
plot(index,threshold)
saveas(gcf,'..\results\figures\sesi.fig')

figure
reac = 1:2*M;
h = stem(reac,[gt;gd;gs]','--','k');
set(h(1),'MarkerFaceColor','blue','MarkerSize',8,'Marker','o')
set(h(2),'MarkerFaceColor','red','MarkerSize',8,'Marker','square')
set(h(3),'MarkerFaceColor','green','MarkerSize',8,'Marker','diamond')
axis([0 2*M+1 -0.04 1.1*max(max(max(gt),max(gd)),max(gs))])
set(gca,'xtick',(1:2:2*M),'FontSize',12)
legend('timing','duration','strength')
xlabel('reaction rate constants','FontSize',14)
ylabel('GESI','FontSize',14)
title('{\bf ROSOSA}','FontSize',14)
clear threshold
threshold(1:2*M+2) = theta;
index = (0:2*M+1);
hold on
plot(index,threshold)
saveas(gcf,'..\results\figures\gesi.fig') 

figure
scatter(sigmat,sigmad,100,fac,'filled')
axis([-0.01 1.05*max(max(sigmat),max(sigmad)) -0.01 1.05*max(max(sigmat),max(sigmad))])
grid on
set(gca,'FontSize',12)
xlabel('timing SESI','FontSize',14); 
ylabel('duration SESI','FontSize',14);
title('{\bf ROSOSA}','FontSize',14)
saveas(gcf,'..\results\figures\dur-tim.fig')
colorbar

figure
scatter(sigmat,sigmas,100,fac,'filled')
axis([-0.01 1.05*max(max(sigmat),max(sigmas)) -0.01 1.05*max(max(sigmat),max(sigmas))])
grid on
set(gca,'FontSize',12)
xlabel('timing SESI','FontSize',14); 
ylabel('strength SESI','FontSize',14);
title('{\bf ROSOSA}','FontSize',14)
saveas(gcf,'..\results\figures\str-tim.fig')
colorbar

figure
scatter(sigmad,sigmas,100,fac,'filled')
axis([-0.02 1.05*max(max(sigmad),max(sigmas)) -0.02 1.05*max(max(sigmad),max(sigmas))])
grid on
set(gca,'FontSize',12)
xlabel('duration SESI','FontSize',14); 
ylabel('strength SESI','FontSize',14);
title('{\bf ROSOSA}','FontSize',14)
saveas(gcf,'..\results\figures\str-dur.fig')
colorbar