% Write sensitivity results (ROSOSA-VSI)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%   H.-X. Zhang, W.P. Dempsey, Jr., and J. Goutsias    %%%%%%%%%%%
%%%%%%%%%%        Probabilistic Sensitivity Analysis of         %%%%%%%%%%%
%%%%%%%%%%            Biochemical Reaction Systems              %%%%%%%%%%%
%%%%%%%%%%  The Journal of Chemical Physics, 131, 094101, 2009  %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%  Reaction and Species-Oriented Sensitivity Analysis  %%%%%%%%%%%
%%%%%%%%%%                   VSI COMPUTATION                    %%%%%%%%%%%
%%%%%%%%%%              Last Modified: 08/11/2009               %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write response means and variances
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\n\nReaction\tMEAN\t\tVARIANCE\n');
for m = 1:M
    Sens = [fac(m);meanTT(m);varmTT(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fprintf(fid,'\n\n\nSpecies\t\tMEAN\t\tVARIANCE\n');
for m = M+1:MN
    Sens = [fac(m)-M;meanTT(m);varmTT(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\n\nReaction\tMEAN\t\tVARIANCE\n');
for m = 1:M
    Sens = [fac(m);meanTT(m);varmTT(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fprintf(fid,'\n\n\nSpecies\t\tMEAN\t\tVARIANCE\n');
for m = M+1:MN
    Sens = [fac(m)-M;meanTT(m);varmTT(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_resp.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'RESPONSE MEAN AND VARIANCE RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\n\nReaction\tMEAN\t\tVARIANCE\n');
for m = 1:M
    Sens = [fac(m);meanTT(m);varmTT(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fprintf(fid,'\n\n\nSpecies\t\tMEAN\t\tVARIANCE\n');
for m = M+1:MN
    Sens = [fac(m)-M;meanTT(m);varmTT(m)];
    fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f',Sens);
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write SESIs, TESIs, and JESIs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION/SPECIES CLASSIFICATION RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nReaction\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = 1:M
    Sens = [fac(m);taut(m);sigmat(m);etat(m)];
    if sigmat(m) <= theta && etat(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmat(m) > theta && etat(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmat(m) <= theta && etat(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmat(m) > theta && etat(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\n\nSpecies\t\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = M+1:MN
    Sens = [fac(m)-M;taut(m);sigmat(m);etat(m)];
    if sigmat(m) <= theta && etat(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmat(m) > theta && etat(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmat(m) <= theta && etat(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmat(m) > theta && etat(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION/SPECIES CLASSIFICATION RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nReaction\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = 1:M
    Sens = [fac(m);taud(m);sigmad(m);etad(m)];
    if sigmad(m) <= theta && etad(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmad(m) > theta && etad(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmad(m) <= theta && etad(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmad(m) > theta && etad(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\n\nSpecies\t\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = M+1:MN
    Sens = [fac(m)-M;taud(m);sigmad(m);etad(m)];
    if sigmad(m) <= theta && etad(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmad(m) > theta && etad(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmad(m) <= theta && etad(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmad(m) > theta && etad(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_sens.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION/SPECIES CLASSIFICATION RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nReaction\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = 1:M
    Sens = [fac(m);taus(m);sigmas(m);etas(m)];
    if sigmas(m) <= theta && etas(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmas(m) > theta && etas(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmas(m) <= theta && etas(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmas(m) > theta && etas(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\n\nSpecies\t\tTESI\t\tSESI\t\tJESI\t\tClassification\n');
for m = M+1:MN
    Sens = [fac(m)-M;taus(m);sigmas(m);etas(m)];
    if sigmas(m) <= theta && etas(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\tNON-INFLUENTIAL',Sens);
    end
    if sigmas(m) > theta && etas(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly)',Sens);
    end
    if sigmas(m) <= theta && etas(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (jointly)',Sens);
    end
    if sigmas(m) > theta && etas(m) > theta
        fprintf(fid,'\n%1.0f\t%14.4f\t%10.4f\t%10.4f\t\t****INFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write singular reaction/species ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR REACTION/SPECIES RANKING RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nFactor\t\t\tSESI\t\t\tClassification\n');
for m = 1:MN
    Sens = [IT(MN-m+1);sigmat(IT(MN-m+1))];
    if sigmat(IT(MN-m+1)) > theta && etat(IT(MN-m+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmat(IT(MN-m+1)) <= theta && etat(IT(MN-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmat(IT(MN-m+1)) > theta && etat(IT(MN-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR REACTION/SPECIES RANKING RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nFactor\t\t\tSESI\t\t\tClassification\n');
for m = 1:MN
    Sens = [ID(MN-m+1);sigmad(ID(MN-m+1))];
    if sigmad(ID(MN-m+1)) > theta && etad(ID(MN-m+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmad(ID(MN-m+1)) <= theta && etad(ID(MN-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmad(ID(MN-m+1)) > theta && etad(ID(MN-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank_singular.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED SINGULAR REACTION/SPECIES RANKING RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nFactor\t\t\tSESI\t\t\tClassification\n');
for m = 1:MN
    Sens = [IS(MN-m+1);sigmas(IS(MN-m+1))];
    if sigmas(IS(MN-m+1)) > theta && etas(IS(MN-m+1)) <= theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly)',Sens);
    end
    if sigmas(IS(MN-m+1)) <= theta && etas(IS(MN-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (jointly)',Sens);
    end
    if sigmas(IS(MN-m+1)) > theta && etas(IS(MN-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL (singularly & jointly)',Sens);
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write PESI's
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for m = 1:MN
    if sigmat(IT(MN-m+1)) <= theta && etat(IT(MN-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for n = 1:MN
            nut(n,n) = 0;
            if nut(IT(MN-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IT(MN-m+1),n,nut(IT(MN-m+1),n));
            end
        end
    end
   if sigmat(IT(MN-m+1)) > theta && etat(IT(MN-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for n = 1:MN
            nut(n,n) = 0;
            if nut(IT(MN-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IT(MN-m+1),n,nut(IT(MN-m+1),n));
            end
        end
    end
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for m = 1:MN
    if sigmad(ID(MN-m+1)) <= theta && etad(ID(MN-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for n = 1:MN
            nud(n,n) = 0;
            if nud(ID(MN-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',ID(MN-m+1),n,nud(ID(MN-m+1),n));
            end
        end
    end
   if sigmad(ID(MN-m+1)) > theta && etad(ID(MN-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for n = 1:MN
            nud(n,n) = 0;
            if nud(ID(MN-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',ID(MN-m+1),n,nud(ID(MN-m+1),n));
            end
        end
    end
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_pesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED PESI (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f\n',theta);
for m = 1:MN
    if sigmas(IS(MN-m+1)) <= theta && etas(IS(MN-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (jointly)\n');
        fprintf(fid,'-------------------------');
        for n = 1:MN
            nus(n,n) = 0;
            if nus(IS(MN-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IS(MN-m+1),n,nus(IS(MN-m+1),n));
            end
        end
    end
   if sigmas(IS(MN-m+1)) > theta && etas(IS(MN-m+1)) > theta
        fprintf(fid,'\n\nINFLUENTIAL (singularly & jointly)\n');
        fprintf(fid,'---------------------------------------');
        for n = 1:MN
            nus(n,n) = 0;
            if nus(IS(MN-m+1),n) > 0
                fprintf(fid,'\n(%1.0f-%2.0f)%8.4f',IS(MN-m+1),n,nus(IS(MN-m+1),n));
            end
        end
    end
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write joint reaction/species ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT REACTION/SPECIES RANKING RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltat);
fprintf(fid,'\n\ngamma = %2.4f',gammat);
fprintf(fid,'\n\n\nFactors\t\t\tDESI\n');
for m = 1:MN*MN
    reac1 = floor((I2T(MN*MN-m+1)-1)/MN)+1;
    reac2 = I2T(MN*MN-m+1)-(reac1-1)*MN;
    if vsigma2t(I2T(MN*MN-m+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2t(I2T(MN*MN-m+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT REACTION/SPECIES RANKING RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltad);
fprintf(fid,'\n\ngamma = %2.4f',gammad);
fprintf(fid,'\n\n\nFactors\t\t\tDESI\n');
for m = 1:MN*MN
    reac1 = floor((I2D(MN*MN-m+1)-1)/MN)+1;
    reac2 = I2D(MN*MN-m+1)-(reac1-1)*MN;
    if vsigma2d(I2D(MN*MN-m+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2d(I2D(MN*MN-m+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank_joint.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED JOINT REACTION/SPECIES RANKING RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\ndelta = %2.4f',deltas);
fprintf(fid,'\n\ngamma = %2.4f',gammas);
fprintf(fid,'\n\n\nFactors\t\t\tDESI\n');
for m = 1:MN*MN
    reac1 = floor((I2S(MN*MN-m+1)-1)/MN)+1;
    reac2 = I2S(MN*MN-m+1)-(reac1-1)*MN;
    if vsigma2s(I2S(MN*MN-m+1)) > theta
        fprintf(fid,'\n(%1.0f-%1.0f)\t%14.4f',reac1,reac2,vsigma2s(I2S(MN*MN-m+1)));
    end
end
fprintf(fid,'\n\nNOTES: delta = 0 implies no joint perturbation effects');
fprintf(fid,'\n       gamma = 0 implies no joint perturbation effects of order > 2');
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write GESI's
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_gesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION RATE CLASSIFICATION RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nRate\t\tGESI\t\tClassification\n');
for m = 1:2*M
    Sens = [fac(m);gt(m)];
    if gt(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t\tNON-INFLUENTIAL',Sens);
    else
        fprintf(fid,'\n%1.0f\t%14.4f\t\t****INFLUENTIAL',Sens);
    end
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_gesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION RATE CLASSIFICATION RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nRate\t\tGESI\t\tClassification\n');
for m = 1:2*M
    Sens = [fac(m);gd(m)];
    if gd(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t\tNON-INFLUENTIAL',Sens);
    else
        fprintf(fid,'\n%1.0f\t%14.4f\t\t****INFLUENTIAL',Sens);
    end
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_gesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION RATE CLASSIFICATION RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nRate\t\tGESI\t\tClassification\n');
for m = 1:2*M
    Sens = [fac(m);gs(m)];
    if gs(m) <= theta
        fprintf(fid,'\n%1.0f\t%14.4f\t\tNON-INFLUENTIAL',Sens);
    else
        fprintf(fid,'\n%1.0f\t%14.4f\t\t****INFLUENTIAL',Sens);
    end
end
fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Write reaction rate ranking results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% TIMING

fid = fopen('..\results\reports\timing_rank_gesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION RATE RANKING RESULTS (TIMING)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nRate\t\t\tGESI\t\t\tClassification\n');
for m = 1:2*M
    Sens = [IGT(2*M-m+1);gt(IGT(2*M-m+1))];
    if gt(IGT(2*M-m+1)) > theta 
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL',Sens);
    end
end
fclose(fid);

% DURATION

fid = fopen('..\results\reports\duration_rank_gesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION RATE RANKING RESULTS (DURATION)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nRate\t\t\tGESI\t\t\tClassification\n');
for m = 1:2*M
    Sens = [IGD(2*M-m+1);gd(IGD(2*M-m+1))];
    if gd(IGD(2*M-m+1)) > theta 
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL',Sens);
    end
end
fclose(fid);

% STRENGTH

fid = fopen('..\results\reports\strength_rank_gesi.txt','w');
fprintf(fid,'\t\t\t\n');
fprintf(fid,'VSI-BASED REACTION RATE RANKING RESULTS (STRENGTH)\n\n');
fprintf(fid,'Number of MC-LHS iterations requested = %1.0f',L);
fprintf(fid,'\n\nNumber of MC-LHS iterations performed = %1.0f',Lactual);
fprintf(fid,'\n\nCPU time (in hours) = %1.0f',tcpu);
fprintf(fid,'\n\nSize of reaction perturbation = %2.4f',rlambda);
fprintf(fid,'\n\nSize of species perturbation = %2.4f',slambda);
fprintf(fid,'\n\nThreshold = %2.4f',theta);
fprintf(fid,'\n\n\nRate\t\t\tGESI\t\t\tClassification\n');
for m = 1:2*M
    Sens = [IGS(2*M-m+1);gs(IGS(2*M-m+1))];
    if gs(IGS(2*M-m+1)) > theta
        fprintf(fid,'\n%1.0f\t%18.4f\t\t\tINFLUENTIAL',Sens);
    end
end
fclose(fid);